tiled.structures.array.Kind
===========================

.. currentmodule:: tiled.structures.array

.. autoclass:: Kind

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Kind.bit_field
      ~Kind.boolean
      ~Kind.complex_floating_point
      ~Kind.datetime
      ~Kind.floating_point
      ~Kind.integer
      ~Kind.other
      ~Kind.string
      ~Kind.timedelta
      ~Kind.unicode
      ~Kind.unsigned_integer
   
   